InputBuilder

Struct InputBuilder 

pub struct InputBuilder<T: FromStr> { /* private fields */ }
‘builder’ used to store the settings that are used to fetch input.

.get() method only takes these settings by reference so can be called multiple times.

This type does not have support for default input value.

Implementations

Source

impl<T: FromStr> InputBuilder<T>

pub fn new() -> Self

Creates a new instance of InputBuilder with default settings.

pub fn get(&self) -> T

‘gets’ the input form the user.

Panics if unable to read input line.

pub fn try_get(&self) -> Result<T>

‘gets’ the input form the user.

Errors

Returns Err if unable to read input line.

pub fn default(self, default: T) -> InputBuilderOnce<T>

Changes or adds a default input value.