pub struct InputBuilderOnce<T: FromStr> { /* private fields */ }Expand description
‘builder’ used to store the settings that are used to fetch input.
.get() method takes ownership of the settings so can be called only once without cloning.
This type has support for default input value.
Implementations